Data Structures API
===================

This section provides detailed API documentation for Furax data structures.

Stokes Parameters
-----------------

.. currentmodule:: furax.obs.stokes

Abstract Base Class
~~~~~~~~~~~~~~~~~~~

.. autoclass:: Stokes
   :members:
   :undoc-members:
   :show-inheritance:

Stokes Implementations
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: StokesI
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: StokesQU  
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: StokesIQU
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: StokesIQUV
   :members:
   :undoc-members:
   :show-inheritance:

Landscapes
----------

.. currentmodule:: furax.obs.landscapes

Abstract Base Classes
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: Landscape
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: StokesLandscape  
   :members:
   :undoc-members:
   :show-inheritance:

Implementations
~~~~~~~~~~~~~~~

.. autoclass:: HealpixLandscape
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: FrequencyLandscape
   :members:
   :undoc-members:
   :show-inheritance:

